@@ -14,7 +14,7 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{x}] =} fmins(@var{f},@var{X0},@var{options},@var{grad},@var{P1},@var{P2}, ...)
+## @deftypefn {Function File} {[@var{x}] =} fmins (@var{f},@var{X0},@var{options},@var{grad},@var{P1},@var{P2}, ...)
 ## 
 ## Find the minimum of a funtion of several variables.
 ## By default the method used is the Nelder&Mead Simplex algorithm
@@ -23,12 +23,14 @@
 ##   fmins(inline('(x(1)-5).^2+(x(2)-8).^4'),[0;0])
 ## 
 ## @strong{Inputs}
-## @table @var 
-## @item f 
+## @c use @asis and explicite @var in @table to avoid makeinfo warning
+## @c `unlikely character , in @var' for `P1, P2, ...'.
+## @table @asis 
+## @item @var{f} 
 ## A string containing the name of the function to minimize
-## @item X0
+## @item @var{X0}
 ## A vector of initial parameters fo the function @var{f}.
-## @item options
+## @item @var{options}
 ## Vector with control parameters (not all parameters are used)
 ## @verbatim
 ## options(1) - Show progress (if 1, default is 0, no progress)
@@ -45,9 +47,9 @@
 ##         although the default in nmsmax is "regular simplex"
 ## options(10) - Maximum number of function evaluations
 ## @end verbatim
-## @item grad
+## @item @var{grad}
 ## Unused (For compatibility with Matlab)
-## @item P1,P2, ...
+## @item @var{P1}, @var{P2}, ...
 ## Optional parameters for function @var{f} 
 ##
 ## @end table
