@@ -362,7 +362,7 @@ function ret = __residmin_stat__ (model_f, pfin, settings, hook)
     endif
 
     ## model function
-    f = @ (p, varargin) f (assign (pfin, o.nonfixed, p), varargin{:});
+    f.f = @ (p, varargin) f.f (assign (pfin, o.nonfixed, p), varargin{:});
 
     ## jacobian of model function
     if (have_dfdp)
