@@ -65,16 +65,18 @@
 ## @end example
 ## but the high degree of covariance amongst them makes this a questionable
 ## operation.
+## @end deftypefn
 ##
-## @deftypefnx {Function File} {[@var{p}, @var{s}, @var{mu}] =} wpolyfit (...)
+## @deftypefn {Function File} {[@var{p}, @var{s}, @var{mu}] =} wpolyfit (...)
 ##
 ## If an additional output @code{mu = [mean(x),std(x)]} is requested then 
 ## the @var{x} values are centered and normalized prior to computing the fit.
 ## This will give more stable numerical results.  To compute a predicted 
 ## @var{y} from the returned model use
 ## @code{y = polyval(p, (x-mu(1))/mu(2)}
+## @end deftypefn
 ##
-## @deftypefnx {Function File} {} wpolyfit (...)
+## @deftypefn {Function File} {} wpolyfit (...)
 ##
 ## If no output arguments are requested, then wpolyfit plots the data,
 ## the fitted line and polynomials defining the standard error range.
@@ -86,8 +88,9 @@
 ## y = polyval([2,3,1],x) + dy.*randn(size(x));
 ## wpolyfit(x,y,dy,2);
 ## @end example
+## @end deftypefn
 ##
-## @deftypefnx {Function File} {} wpolyfit (..., 'origin')
+## @deftypefn {Function File} {} wpolyfit (..., 'origin')
 ##
 ## If 'origin' is specified, then the fitted polynomial will go through
 ## the origin.  This is generally ill-advised.  Use with caution.
@@ -141,7 +144,7 @@ function [p_out, s, mu] = wpolyfit (varargin)
     y = A(:,2);
     x = A(:,1);
   else
-    usage ("wpolyfit (x, y [, dy], n [, 'origin'])");
+    print_usage ();
   end
 
   if (length(origin) == 0)
